=================
API Documentation
=================

This is the API documentation for ``scikit-hubness``.

.. _data_ref:

Analysis: :mod:`skhubness.analysis`
===================================

.. automodule:: skhubness.analysis
    :no-members:
    :no-inherited-members:
    :noindex:

.. currentmodule:: skhubness

.. autosummary::
   :nosignatures:
   :toctree: _autosummary

   analysis.Hubness


Neighbors: :mod:`skhubness.neighbors`
=====================================

.. automodule:: skhubness.neighbors
    :no-members:
    :no-inherited-members:
    :noindex:

.. currentmodule:: skhubness

.. autosummary::
   :nosignatures:
   :toctree: _autosummary

   neighbors.BallTree
   neighbors.DistanceMetric
   neighbors.KDTree
   neighbors.HNSW
   neighbors.KNeighborsClassifier
   neighbors.KNeighborsRegressor
   neighbors.LSH
   neighbors.NearestCentroid
   neighbors.NearestNeighbors
   neighbors.RadiusNeighborsClassifier
   neighbors.RadiusNeighborsRegressor
   neighbors.kneighbors_graph
   neighbors.radius_neighbors_graph
   neighbors.KernelDensity
   neighbors.LocalOutlierFactor
   neighbors.NeighborhoodComponentsAnalysis


Reduction: :mod:`skhubness.reduction`
=====================================

.. automodule:: skhubness.reduction
    :no-members:
    :no-inherited-members:
    :noindex:

.. currentmodule:: skhubness

.. autosummary::
   :nosignatures:
   :toctree: _autosummary

   reduction.MutualProximity
   reduction.LocalScaling



